@@ -11,10 +11,14 @@
 #'  functions. If parameters need to be modified, `update()` can be
 #'  used in lieu of recreating the object from scratch.
 #'
-#' @param mode A single character string for the type of model.
+#' @param mode A single character string for the prediction outcome mode.
 #'  Possible values for this model are "unknown", "regression", or
 #'  "classification".
 #'
+#' @param engine A single character string specifying what computational
+#'  engine to use for fitting. Possible engines are listed below.
+#'  The default for this model is `"brms"`.
+#'
 #' @param formula.override Overrides the formula; for details see
 #'  \code{\link[brms]{brmsformula}}.
 #'
@@ -62,10 +66,10 @@
 #' summary(bayesian_mod$fit)
 #' }
 #'
-#' # -------------------------------------------------------------------------
 #' @export
 bayesian <-
   function(mode = "regression",
+           engine = "brms",
            formula.override = NULL,
            family = NULL,
            prior = NULL,
@@ -127,7 +131,7 @@ bayesian <-
       eng_args = NULL,
       mode = mode,
       method = NULL,
-      engine = NULL
+      engine = engine
     )
   }
 
@@ -171,6 +175,7 @@ translate.bayesian <- function(x, engine = x$engine, ...) {
 #' @return An updated model specification.
 #'
 #' @examples
+#'
 #' model <- bayesian(inits = "random")
 #' model
 #' update(model, inits = "0")
